@@ -11,6 +11,7 @@ use Perl6::Pod::Block::para;
 use Perl6::Pod::Block::table;
 use Perl6::Pod::Block::output;
 use Perl6::Pod::Block::input;
+use Perl6::Pod::Block::nested;
 use Perl6::Pod::Parser::NOTES;
 use Perl6::Pod::FormattingCode::A;
 use Perl6::Pod::FormattingCode::C;
@@ -48,6 +49,7 @@ use constant {
         table   => 'Perl6::Pod::Block::table',
         output  => 'Perl6::Pod::Block::output',
         input   => 'Perl6::Pod::Block::input',
+        nested  => 'Perl6::Pod::Block::nested',
         '_NOTES_'   => 'Perl6::Pod::Parser::NOTES',
         'C<>'   => 'Perl6::Pod::FormattingCode::C',
         'M<>'   => 'Perl6::Pod::FormattingCode::M',
