@@ -1,4 +1,4 @@
-#$Id: Pod2Events.pm 552 2009-06-01 18:26:08Z zag $
+#$Id$
 #
 #  Test blocks events
 package Perl6::Pod::Parser::Pod2Events;
@@ -12,7 +12,8 @@ use base qw/ XML::ExtOn /;
 
 use constant {
     NEW_LINE  => qr/^ \s* $/xms,
-    DIRECTIVE => qr/^(begin|config|encoding|end|for|use)$/xms,
+    DIRECTIVE => qr/^(begin|config|encoding|end|for|use|alias)$/xms,
+    BLOCK_NULL_CONTENT => qr/^(config|encoding|use|alias)$/xms,
 };
 
 =head2 parse_config_str
@@ -69,7 +70,7 @@ sub stop_config {
     $elem->{NAME} = $name;
     $elem->{OPT} = join " ", @block_opt;
     my $parser = $self->{parser} || die '$self->{parser} - > undef !';
-    $parser->start_block( $elem->{NAME}, $elem->{OPT}, $elem->{LINE_NUM} );
+    $parser->start_block( $elem->{NAME}, $elem->{OPT}, $elem->{LINE_NUM}, $elem );
 }
 
 sub on_characters {
@@ -78,12 +79,13 @@ sub on_characters {
     my $text = shift;
     return unless defined $text;
     my $parser = $self->{parser} || die '$self->{parser} - > undef !';
-    if ( $text =~ /${\( NEW_LINE )}/ ) {
-        $self->_flush_para( $elem )
-    }
-    else {
+
+#    if ( $text =~ /${\( NEW_LINE )}/ ) {
+#        $self->_flush_para( $elem )
+#    }
+#    else {
         $elem->{TEXT} .= $text;
-    }
+#    }
     return;
 }
 
@@ -91,7 +93,7 @@ sub _flush_para {
     my $self = shift;
     my $elem = shift || return;
     if ( my $agregated = delete $elem->{TEXT} ) {
-        my $parser = $self->{parser} || die '$self->{parser} - > undef !';
+        my $parser = $self->{parser} || die '$self->{parser} -> undef !';
         $parser->para($agregated);
     }
     return
@@ -103,6 +105,7 @@ sub on_end_element {
 
     #flush agregated characters
     $self->_flush_para( $elem);
+
     my $parser = $self->{parser} || die '$self->{parser} - > undef !';
     $parser->end_block( $elem->{NAME}, $elem->{OPT}, $elem->{END_LINE} );
     $elem;
@@ -124,11 +127,11 @@ sub new_line {
             $self->stop_config($el);
 
         }
-        else {
+#        else {
             if ( $el->local_name eq 'begin' ) {
                 $self->characters( { Data => "\n" } );
             }
-        }
+#        }
 
         #skip already stopped
         if ( $el->local_name ne 'begin' ) {
@@ -147,12 +150,13 @@ sub before_start_directive {
     my $str_num = shift;
     if ( my $current = $self->current_element ) {
         $self->stop_config($current);
-        $self->_flush_para( $current );
-        unless ( $current->local_name eq 'begin' ) {
+        if ( $current->local_name eq 'begin' ) {
+                $self->_flush_para( $current );
+        } else {
             $current->{END_LINE} = $str_num;
             $self->end_element($current);
 
-        }
+        } 
     }
 }
 
@@ -181,7 +185,9 @@ sub parse {
                     unless ( $data =~ /(\S+)/ ) {
                         die("Error: bad =end  at line $str_num: $_");
                     }
-                    if ( $curr->{NAME} ne $data ) {
+                    my ($name) = $data =~ m/(\w+)/;
+
+                    if ( $curr->{NAME} ne $name ) {
                         die
 "Error: Expected '=end  $curr->{NAME}'  at line $str_num:  $_";
                     }
@@ -193,6 +199,8 @@ sub parse {
                     my $block = $self->mk_element($name);
                     $block->{PARA}     = $_;
                     $block->{LINE_NUM} = $str_num;
+                    #save RAW sting of line
+                    $block->{RAW} .= $_;
 
                     #start element
                     $self->start_element($block);
@@ -224,6 +232,8 @@ sub parse {
 
                         #get config string
                         my $conf = $_;
+                        #save RAW sting of config part
+                        $current->{RAW} .= $conf;
                         $conf =~ s/^=\s+(.*)?/$1/;
                         $self->parse_config_str( $current, $conf );
                     }
@@ -236,12 +246,21 @@ sub parse {
             1;
           }
           || ( !$self->in_ambient_mode ) && do {
-
-            #check if new line
-            if (/${\( NEW_LINE )}/) {
+          # close stop
+           my $current = $self->current_element;
+           unless ( $current->{STOP_CONFIG} ) {
+             $self->stop_config($current);
+            }
+           my $lname = $self->current_element->local_name;
+           #check if new line
+            if (/${\( NEW_LINE )}/ && $lname ne 'begin') {
                 $self->new_line($str_num);
             }
             else {
+                #for directives use|config|encoding
+                if ($lname =~ /${\( BLOCK_NULL_CONTENT )}/) {
+                  $self->before_start_directive(); 
+                }
                 $self->characters( { Data => $_ } );
             }
           }
