@@ -75,6 +75,7 @@ use Perl6::Pod::To::XHTML::ProcessHeadings;
 use Perl6::Pod::To::XHTML::MakeHead;
 use Perl6::Pod::To::XHTML::MakeBody;
 use Perl6::Pod::Parser::Doformatted;
+use Perl6::Pod::Parser::NestedAttr;
 use XML::ExtOn('create_pipe');
 use base qw/Perl6::Pod::To::XML/;
 use constant POD_URI => 'http://perlcabal.org/syn/S26.html';
@@ -99,6 +100,7 @@ sub new {
     $self->{out_put} =
       create_pipe( 'Perl6::Pod::To::XHTML::ProcessHeadings', $self->{out_put} );
     return create_pipe(
+        'Perl6::Pod::Parser::NestedAttr',
         'Perl6::Pod::Parser::Doformatted',
         'Perl6::Pod::Parser::ListLevels',
         'Perl6::Pod::Parser::AddHeadLevels',
